@@ -79,6 +79,11 @@ class AggregatedMatrix:
         return self.__matrix
 
 
+def is_too_close_to_diagonal(row_start, column_start, row_end, column_end, resolution):
+    return abs(row_start - column_start) < 2 * resolution and \
+           abs(row_end - column_end) < 2 * resolution
+
+
 class DeploySpears:
     def __init__(self, all_model_sets: list, batch_size: int, num_straw_workers: int, filepath: str,
                  resolution: int, max_examples_in_ram: int, matrix_width: int, threshold: float,
@@ -198,7 +203,8 @@ class DeploySpears:
                             num_total_slices += 2
             else:
                 for x1 in range(0, exceed_boundaries_limit, self.get_width() - buffer):
-                    for y1 in range(x1, min(x1 + near_diag_distance, exceed_boundaries_limit), self.get_width() - buffer):
+                    for y1 in range(x1, min(x1 + near_diag_distance, exceed_boundaries_limit),
+                                    self.get_width() - buffer):
                         temp.append((chrom, x1, y1))
                         if x1 == y1:
                             num_total_slices += 1
@@ -263,7 +269,8 @@ class DeploySpears:
                 print("DONE GETTING ALL REGIONS VIA STRAW!!!", flush=True)
 
     @staticmethod
-    def find_max_in_connected_components(prediction, chrom1, x0, y0, handler, resolution):
+    def find_max_in_connected_components(prediction, chrom1, x0, y0, handler, resolution,
+                                         ignore_on_diagonal: bool = False):
         labeled, n_components = label(prediction, np.ones((3, 3), dtype=np.int))
         for num in range(n_components):
             highlighted_region = (labeled == (num + 1)) * prediction
@@ -275,6 +282,9 @@ class DeploySpears:
                 row_end = row_start + resolution
                 column_start = (y0 + maxIndex[1]) * resolution
                 column_end = column_start + resolution
+                if ignore_on_diagonal and is_too_close_to_diagonal(row_start, column_start, row_end, column_end,
+                                                                   resolution):
+                    continue
                 if row_start < column_start:
                     handler.add_prediction(chrom1, chrom1, row_start, row_end, column_start, column_end, max_prediction)
                 else:
@@ -306,7 +316,8 @@ class DeploySpears:
                                                         self.__nms_handlers[k], self.__resolution)
             else:
                 self.find_max_in_connected_components(prediction[:, :, k], chrom1, x1, y1,
-                                                      self.__nms_handlers[k], self.__resolution)
+                                                      self.__nms_handlers[k], self.__resolution,
+                                                      ignore_on_diagonal=(k == 0))  # for loops
 
     def get_threshold(self):
         return self.__threshold
